@@ -45,8 +45,7 @@ class API(APIBase):
         self.session = requests.Session()
         self.session.headers = {
             "Authorization": token,
-            "Content-Type": "application/json",
-            "Accept": f"application/json; version={self.api_version}",
+            "Content-Type": "application/json"
         }
 
         # Test API authentication by fetching session info
@@ -99,7 +98,7 @@ class API(APIBase):
         return json.loads(response.content)
 
     @beartype
-    def post(self, url: str, data: str = None, valid_codes: list = [201]):
+    def post(self, url: str, data: str = None, valid_codes: list = [200, 201]):
         """Performs an HTTP POST request and handles errors."""
         url = convert_to_api_url(url)
         response = self.session.post(url=url, data=data)
